==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/BackgroundPositionModeType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BackgroundPositionModeType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="BackgroundPositionModeType"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="custom"/&gt;
 *     &lt;enumeration value="top_left"/&gt;
 *     &lt;enumeration value="top_center"/&gt;
 *     &lt;enumeration value="top_right"/&gt;
 *     &lt;enumeration value="center_left"/&gt;
 *     &lt;enumeration value="center_center"/&gt;
 *     &lt;enumeration value="center_right"/&gt;
 *     &lt;enumeration value="bottom_left"/&gt;
 *     &lt;enumeration value="bottom_center"/&gt;
 *     &lt;enumeration value="bottom_right"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "BackgroundPositionModeType")
@XmlEnum
public enum BackgroundPositionModeType {

    @XmlEnumValue("custom")
    CUSTOM("custom"),
    @XmlEnumValue("top_left")
    TOP_LEFT("top_left"),
    @XmlEnumValue("top_center")
    TOP_CENTER("top_center"),
    @XmlEnumValue("top_right")
    TOP_RIGHT("top_right"),
    @XmlEnumValue("center_left")
    CENTER_LEFT("center_left"),
    @XmlEnumValue("center_center")
    CENTER_CENTER("center_center"),
    @XmlEnumValue("center_right")
    CENTER_RIGHT("center_right"),
    @XmlEnumValue("bottom_left")
    BOTTOM_LEFT("bottom_left"),
    @XmlEnumValue("bottom_center")
    BOTTOM_CENTER("bottom_center"),
    @XmlEnumValue("bottom_right")
    BOTTOM_RIGHT("bottom_right");
    private final String value;

    BackgroundPositionModeType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static BackgroundPositionModeType fromValue(String v) {
        for (BackgroundPositionModeType c: BackgroundPositionModeType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/BackgroundPositionModeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BackgroundPositionModeType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>{@code
 * <simpleType name="BackgroundPositionModeType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="custom"/>
 *     <enumeration value="top_left"/>
 *     <enumeration value="top_center"/>
 *     <enumeration value="top_right"/>
 *     <enumeration value="center_left"/>
 *     <enumeration value="center_center"/>
 *     <enumeration value="center_right"/>
 *     <enumeration value="bottom_left"/>
 *     <enumeration value="bottom_center"/>
 *     <enumeration value="bottom_right"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "BackgroundPositionModeType")
@XmlEnum
public enum BackgroundPositionModeType {

    @XmlEnumValue("custom")
    CUSTOM("custom"),
    @XmlEnumValue("top_left")
    TOP_LEFT("top_left"),
    @XmlEnumValue("top_center")
    TOP_CENTER("top_center"),
    @XmlEnumValue("top_right")
    TOP_RIGHT("top_right"),
    @XmlEnumValue("center_left")
    CENTER_LEFT("center_left"),
    @XmlEnumValue("center_center")
    CENTER_CENTER("center_center"),
    @XmlEnumValue("center_right")
    CENTER_RIGHT("center_right"),
    @XmlEnumValue("bottom_left")
    BOTTOM_LEFT("bottom_left"),
    @XmlEnumValue("bottom_center")
    BOTTOM_CENTER("bottom_center"),
    @XmlEnumValue("bottom_right")
    BOTTOM_RIGHT("bottom_right");
    private final String value;

    BackgroundPositionModeType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static BackgroundPositionModeType fromValue(String v) {
        for (BackgroundPositionModeType c: BackgroundPositionModeType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
